===============
Getting started
===============

Installation
------------
- Windows installers for PyCorrFit are available at the `release page <https://github.com/FCS-analysis/PyCorrFit/releases>`_.
- On Debian-based systems, install via ``apt-get install pycorrfit``.
- If you have Python 3.6 installed, you may install PyCorrFit via ``pip install pycorrfit[GUI]``.
  After the installation, type ``pycorrfit`` in a command shell to start PyCorrFit.


Documentation
-------------
The documentation is in the process of being transferred entirely to
readthedocs.org. Currently, it is scattered across several
places and it is most-likely outdated:

- Original LaTeX-based PDF file (outdated): https://github.com/FCS-analysis/PyCorrFit/wiki/PyCorrFit_doc.pdf
- Wiki pages: https://github.com/FCS-analysis/PyCorrFit/wiki/
- A tutorial: https://github.com/FCS-analysis/PyCorrFit/wiki/Tutorial
- How to write model functions: https://github.com/FCS-analysis/PyCorrFit/wiki/Writing-model-functions
